************
Installation
************


Stable release
==============

To install United, run this command in your terminal:

.. code-block:: console

   $ pip install united

This is the preferred method to install United, as it
will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.
Note that on systems that still use legacy Python as the default, you will have
to use ``pip3`` instead of ``pip``, as United only
supports Python 3.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
============

The sources for United can be downloaded from the
`Github repo`_.

You can either clone the public repository:

.. code-block:: console

   $ git clone git://github.com/emtpb/united

Or download the `tarball`_:

.. code-block:: console

   $ curl -OL https://github.com/emtpb/united/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

   $ python setup.py install


.. _Github repo: https://github.com/emtpb/united
.. _tarball: https://github.com/emtpb/united/tarball/master
